Lemonade Server

{{SERVER_MODELS_JS}}
Loading...
Use Lemonade with your favorite app
Open WebUI Continue Gaia AnythingLLM AI Dev Gallery LM-Eval CodeGPT AI Toolkit
Temperature: Controls randomness in responses (0 = deterministic, 2 = very random)
Top K: Limits token selection to top K most likely tokens
Top P: Nucleus sampling - considers tokens with cumulative probability up to P
Repeat Penalty: Penalty for repeating tokens (1 = no penalty, >1 = less repetition)
Model Name ⓘ
user.
Checkpoint ⓘ
Recipe ⓘ
More info
mmproj file ⓘ Reasoning ⓘ